Transfer
A Transfer marks a payment state from a buyer wallet to a seller wallet.
GET a list of transfers
Query a list of transfers. Parameters for pagination, query condition and sort order can be used for this method, see pagination and query pages for details.
Get a list of transfers example
curl /v2/transfers?page=1&per_page=20&filter=&sort= -H "X-Api-Key:.." -H "Authorization:JWT .."
Successful return object:
{
"page": 1,
"per_page": 20,
"data": []
}
GET a single transfers by ID
Query a transfers object by ID.
Get a single transfers example
curl /v2/transfers/1 -H "X-Api-Key:.." -H "Authorization:JWT .."
Successful return object:
{
"id": 12,
"app_id": 1234,
"from_id": 1,
"to_id": 2,
"currency": "USD",
"amount": 345,
"payin_id": 3,
"seller_id": 4,
"result": "",
"status": "P",
"created_at": ""
}
POST a transfers
Create a transfers entity.
| Field | Type | Description |
|---|---|---|
| app_id | int | App's ID |
| from_id | int | buyers wallet ID |
| to_id | int | sellers wallet ID |
| currency | string | |
| amount | int | |
| payin_id | int | PayIn.ID |
| seller_id | int | Seller.ID |
| result | string | result from gateway |
POST to create a transfers:
curl -X POST -d '{"app_id":1,"currency":"EUR"}' /v2/transfers -H "X-Api-Key:.." -H "Authorization:JWT .."
Successful return:
{
"status": "OK",
"id": 123
}
PUT a transfers
Update a transfers entity.
Update a transfers example
curl -X PUT -d '{"result":"OK"}' /v2/transfers/1 -H "X-Api-Key:.." -H "Authorization:JWT .."
Successful return:
{
"status": "OK"
}
DELETE a transfers
Delete a transfers entity. Only system admin role can make this request.
Delete a transfers example
curl -X DELETE /v2/transfers/1 -H "X-Api-Key:.." -H "Authorization:JWT .."
Successful return:
{
"status": "OK"
}